@@ -17,6 +17,8 @@
 #define _GNU_SOURCE 1
 #define _POSIX_PTHREAD_SEMANTICS 1
 #define _TANDEM_SOURCE 1
+#define RUBY_SYMBOL_EXPORT_BEGIN _Pragma("GCC visibility push(default)")
+#define RUBY_SYMBOL_EXPORT_END _Pragma("GCC visibility pop")
 #define HAVE_DIRENT_H 1
 #define HAVE__BOOL 1
 #define HAVE_STDBOOL_H 1
@@ -36,13 +38,14 @@
 #define HAVE_A_OUT_H 1
 #define HAVE_UTIME_H 1
 #define HAVE_SYS_RESOURCE_H 1
-#define HAVE_NETINET_IN_SYSTM_H 1
 #define HAVE_FLOAT_H 1
 #define HAVE_IEEEFP_H 1
 #define HAVE_LANGINFO_H 1
 #define HAVE_LOCALE_H 1
 #define HAVE_TIME_H 1
 #define HAVE_SYS_SOCKET_H 1
+#define HAVE_GMP_H 1
+#define HAVE_LIBGMP 1
 #define WORDS_BIGENDIAN 1
 #define HAVE_LONG_LONG 1
 #define HAVE_OFF_T 1
@@ -51,40 +54,59 @@
 #define SIZEOF_LONG 4
 #define SIZEOF_LONG_LONG 8
 #define SIZEOF___INT64 0
+#define SIZEOF___INT128 0
 #define SIZEOF_OFF_T 8
 #define SIZEOF_VOIDP 4
 #define SIZEOF_FLOAT 4
 #define SIZEOF_DOUBLE 8
 #define SIZEOF_TIME_T 8
+#define SIZEOF_CLOCK_T 8
 #define PRI_LL_PREFIX "ll"
 #define rb_pid_t pid_t
+#define SIGNEDNESS_OF_PID_T -1
 #define PIDT2NUM(v) INT2NUM(v)
 #define NUM2PIDT(v) NUM2INT(v)
 #define PRI_PIDT_PREFIX PRI_INT_PREFIX
 #define rb_uid_t uid_t
+#define SIGNEDNESS_OF_UID_T +1
 #define UIDT2NUM(v) UINT2NUM(v)
 #define NUM2UIDT(v) NUM2UINT(v)
 #define PRI_UIDT_PREFIX PRI_INT_PREFIX
 #define rb_gid_t gid_t
+#define SIGNEDNESS_OF_GID_T +1
 #define GIDT2NUM(v) UINT2NUM(v)
 #define NUM2GIDT(v) NUM2UINT(v)
 #define PRI_GIDT_PREFIX PRI_INT_PREFIX
 #define rb_time_t time_t
+#define SIGNEDNESS_OF_TIME_T -1
 #define TIMET2NUM(v) LL2NUM(v)
 #define NUM2TIMET(v) NUM2LL(v)
 #define PRI_TIMET_PREFIX PRI_LL_PREFIX
 #define rb_dev_t dev_t
+#define SIGNEDNESS_OF_DEV_T -1
 #define DEVT2NUM(v) INT2NUM(v)
 #define NUM2DEVT(v) NUM2INT(v)
 #define PRI_DEVT_PREFIX PRI_INT_PREFIX
 #define rb_mode_t mode_t
+#define SIGNEDNESS_OF_MODE_T +1
 #define MODET2NUM(v) UINT2NUM(v)
 #define NUM2MODET(v) NUM2UINT(v)
 #define PRI_MODET_PREFIX PRI_INT_PREFIX
 #define rb_rlim_t rlim_t
+#define SIGNEDNESS_OF_RLIM_T +1
 #define RLIM2NUM(v) ULL2NUM(v)
 #define NUM2RLIM(v) NUM2ULL(v)
 #define PRI_RLIM_PREFIX PRI_LL_PREFIX
+#define rb_off_t off_t
+#define SIGNEDNESS_OF_OFF_T -1
+#define OFFT2NUM(v) LL2NUM(v)
+#define NUM2OFFT(v) NUM2LL(v)
+#define PRI_OFFT_PREFIX PRI_LL_PREFIX
+#define rb_clockid_t clockid_t
+#define SIGNEDNESS_OF_CLOCKID_T -1
+#define CLOCKID2NUM(v) INT2NUM(v)
+#define NUM2CLOCKID(v) NUM2INT(v)
+#define PRI_CLOCKID_PREFIX PRI_INT_PREFIX
 #define HAVE_PROTOTYPES 1
 #define TOKEN_PASTE(x,y) x##y
 #define STRINGIZE(expr) STRINGIZE0(expr)
@@ -93,10 +115,12 @@
 #define NORETURN(x) __attribute__ ((noreturn)) x
 #define DEPRECATED(x) __attribute__ ((deprecated)) x
 #define NOINLINE(x) __attribute__ ((noinline)) x
+#define HAVE_ATTRIBUTE_FUNCTION_ALIAS 1
 #define RUBY_ALIAS_FUNCTION_TYPE(type, prot, name, args) type prot __attribute__((alias(#name)));
 #define RUBY_ALIAS_FUNCTION_VOID(prot, name, args) RUBY_ALIAS_FUNCTION_TYPE(void, prot, name, args)
 #define RUBY_FUNC_EXPORTED __attribute__ ((visibility("default"))) extern
 #define HAVE_DECL_SYS_NERR 1
+#define HAVE_DECL_GETENV 1
 #define SIZEOF_SIZE_T 4
 #define SIZEOF_PTRDIFF_T 4
 #define PRI_SIZE_PREFIX "z"
@@ -119,6 +143,7 @@
 #define HAVE_STRUCT_STAT_ST_CTIMESPEC 1
 #define HAVE_STRUCT_STAT_ST_CTIMENSEC 1
 #define HAVE_STRUCT_TIMEVAL 1
+#define SIZEOF_STRUCT_TIMEVAL_TV_SEC SIZEOF_TIME_T
 #define HAVE_STRUCT_TIMESPEC 1
 #define HAVE_STRUCT_TIMEZONE 1
 #define HAVE_CLOCKID_T 1
@@ -170,106 +195,100 @@
 #define HAVE_FFS 1
 #define HAVE_SETPROCTITLE 1
 #define HAVE_SIGNBIT 1
-#define HAVE_FMOD 1
-#define HAVE_KILLPG 1
-#define HAVE_WAIT4 1
-#define HAVE_WAITPID 1
-#define HAVE_FORK 1
-#define HAVE_SYSCALL 1
 #define HAVE___SYSCALL 1
-#define HAVE_CHROOT 1
-#define HAVE_GETCWD 1
-#define HAVE_TRUNCATE 1
-#define HAVE_FTRUNCATE 1
-#define HAVE_FTELLO 1
-#define HAVE_TIMES 1
-#define HAVE_UTIMES 1
-#define HAVE_UTIMENSAT 1
-#define HAVE_FCNTL 1
-#define HAVE_LOCKF 1
-#define HAVE_LSTAT 1
-#define HAVE_FSEEKO 1
-#define HAVE_LINK 1
-#define HAVE_SYMLINK 1
-#define HAVE_READLINK 1
-#define HAVE_READDIR_R 1
-#define HAVE_FSYNC 1
-#define HAVE_FDATASYNC 1
-#define HAVE_FCHOWN 1
-#define HAVE_SETITIMER 1
-#define HAVE_SETEUID 1
-#define HAVE_SETREUID 1
-#define HAVE_SETRESUID 1
-#define HAVE_SOCKETPAIR 1
-#define HAVE_SETEGID 1
-#define HAVE_SETREGID 1
-#define HAVE_SETRESGID 1
-#define HAVE_ISSETUGID 1
-#define HAVE_PAUSE 1
-#define HAVE_LCHOWN 1
-#define HAVE_GETPGRP 1
-#define HAVE_SETPGRP 1
-#define HAVE_GETPGID 1
-#define HAVE_SETPGID 1
-#define HAVE_INITGROUPS 1
-#define HAVE_GETGROUPS 1
-#define HAVE_SETGROUPS 1
-#define HAVE_GETPRIORITY 1
-#define HAVE_GETRLIMIT 1
-#define HAVE_SETRLIMIT 1
-#define HAVE_SYSCONF 1
-#define HAVE_CLOSE 1
-#define HAVE_GETPWNAM_R 1
-#define HAVE_GETGRNAM_R 1
-#define HAVE_DLOPEN 1
-#define HAVE_SIGPROCMASK 1
-#define HAVE_SIGACTION 1
-#define HAVE_SIGSETJMP 1
-#define HAVE__SETJMP 1
 #define HAVE__LONGJMP 1
-#define HAVE_GETSID 1
-#define HAVE_SETSID 1
-#define HAVE_TELLDIR 1
-#define HAVE_SEEKDIR 1
-#define HAVE_FCHMOD 1
-#define HAVE_COSH 1
-#define HAVE_SINH 1
-#define HAVE_TANH 1
-#define HAVE_LOG2 1
-#define HAVE_ROUND 1
-#define HAVE_LLABS 1
-#define HAVE_SETUID 1
-#define HAVE_SETGID 1
-#define HAVE_DAEMON 1
-#define HAVE_SETENV 1
-#define HAVE_UNSETENV 1
-#define HAVE_MKTIME 1
-#define HAVE_TIMEGM 1
-#define HAVE_GMTIME_R 1
+#define HAVE__SETJMP 1
+#define HAVE_CHROOT 1
 #define HAVE_CLOCK_GETTIME 1
-#define HAVE_GETTIMEOFDAY 1
-#define HAVE_POLL 1
-#define HAVE_PPOLL 1
-#define HAVE_PREAD 1
-#define HAVE_SHUTDOWN 1
-#define HAVE_SIGALTSTACK 1
+#define HAVE_COSH 1
+#define HAVE_DAEMON 1
 #define HAVE_DL_ITERATE_PHDR 1
+#define HAVE_DLOPEN 1
 #define HAVE_DUP 1
 #define HAVE_DUP3 1
-#define HAVE_PIPE2 1
-#define HAVE_POSIX_MEMALIGN 1
+#define HAVE_ENDGRENT 1
+#define HAVE_FCHMOD 1
+#define HAVE_FCHOWN 1
+#define HAVE_FCNTL 1
+#define HAVE_FDATASYNC 1
+#define HAVE_FMOD 1
+#define HAVE_FORK 1
+#define HAVE_FSYNC 1
+#define HAVE_FTRUNCATE 1
+#define HAVE_GETCWD 1
+#define HAVE_GETGRNAM_R 1
+#define HAVE_GETGROUPS 1
+#define HAVE_GETPGID 1
+#define HAVE_GETPGRP 1
+#define HAVE_GETPRIORITY 1
+#define HAVE_GETPWNAM_R 1
+#define HAVE_GETRLIMIT 1
+#define HAVE_GETSID 1
+#define HAVE_GETTIMEOFDAY 1
+#define HAVE_GMTIME_R 1
+#define HAVE_INITGROUPS 1
 #define HAVE_IOCTL 1
-#define RUBY_SETJMP(env) _setjmp(env)
-#define RUBY_LONGJMP(env,val) _longjmp(env,val)
-#define RUBY_JMP_BUF jmp_buf
+#define HAVE_ISSETUGID 1
+#define HAVE_KILLPG 1
+#define HAVE_LCHOWN 1
+#define HAVE_LINK 1
+#define HAVE_LLABS 1
+#define HAVE_LOCKF 1
+#define HAVE_LOG2 1
+#define HAVE_LSTAT 1
+#define HAVE_MBLEN 1
+#define HAVE_MEMRCHR 1
+#define HAVE_MKTIME 1
+#define HAVE_PIPE2 1
+#define HAVE_POLL 1
+#define HAVE_POSIX_MEMALIGN 1
+#define HAVE_PPOLL 1
+#define HAVE_PREAD 1
+#define HAVE_READLINK 1
+#define HAVE_ROUND 1
+#define HAVE_SEEKDIR 1
+#define HAVE_SETEGID 1
+#define HAVE_SETENV 1
+#define HAVE_SETEUID 1
+#define HAVE_SETGID 1
+#define HAVE_SETGROUPS 1
+#define HAVE_SETPGID 1
+#define HAVE_SETPGRP 1
+#define HAVE_SETREGID 1
+#define HAVE_SETRESGID 1
+#define HAVE_SETRESUID 1
+#define HAVE_SETREUID 1
+#define HAVE_SETRLIMIT 1
+#define HAVE_SETSID 1
+#define HAVE_SETUID 1
+#define HAVE_SHUTDOWN 1
+#define HAVE_SIGACTION 1
+#define HAVE_SIGALTSTACK 1
+#define HAVE_SIGPROCMASK 1
+#define HAVE_SINH 1
+#define HAVE_SYMLINK 1
+#define HAVE_SYSCALL 1
+#define HAVE_SYSCONF 1
+#define HAVE_TANH 1
+#define HAVE_TELLDIR 1
+#define HAVE_TIMEGM 1
+#define HAVE_TIMES 1
+#define HAVE_TRUNCATE 1
+#define HAVE_UNSETENV 1
+#define HAVE_UTIMENSAT 1
+#define HAVE_UTIMES 1
+#define HAVE_WAIT4 1
+#define HAVE_WAITPID 1
+#define HAVE_BUILTIN___BUILTIN_CLZ 1
+#define HAVE_BUILTIN___BUILTIN_CLZL 1
+#define HAVE_BUILTIN___BUILTIN_CLZLL 1
+#define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR 1
+#define HAVE_BUILTIN___BUILTIN_TYPES_COMPATIBLE_P 1
+#define HAVE_CLOCK_GETRES 1
 #define HAVE_STRUCT_TM_TM_ZONE 1
 #define HAVE_TM_ZONE 1
 #define HAVE_STRUCT_TM_TM_GMTOFF 1
-#define HAVE_DAYLIGHT 1
-#define HAVE_VAR_TIMEZONE 1
-#define TYPEOF_VAR_TIMEZONE long
 #define HAVE_TIMEZONE 1
-#define TIMEZONE_VOID 1
 #define NEGATIVE_TIME_T 1
 #define POSIX_SIGNAL 1
 #define RSHIFT(x,y) ((x)>>(int)(y))
@@ -296,7 +315,10 @@
 #define DLEXT_MAXLEN 3
 #define DLEXT ".so"
 #define LIBDIR_BASENAME "lib"
+#define RUBY_SETJMP(env) _setjmp((env))
+#define RUBY_LONGJMP(env,val) _longjmp((env),val)
+#define RUBY_JMP_BUF jmp_buf
 #define HAVE_PTHREAD_H 1
 #define HAVE_MEMMEM 1
-#define RUBY_EXEC_PREFIX "/usr/local"
+#define RUBY_PLATFORM "hppa-openbsd"
 #endif /* INCLUDE_RUBY_CONFIG_H */
