@@ -205,6 +205,7 @@
 #define HAVE_DL_ITERATE_PHDR 1
 #define HAVE_DLOPEN 1
 #define HAVE_DUP 1
+#define HAVE_DUP3 1
 #define HAVE_ENDGRENT 1
 #define HAVE_FCHMOD 1
 #define HAVE_FCHOWN 1
@@ -238,6 +239,7 @@
 #define HAVE_MBLEN 1
 #define HAVE_MEMRCHR 1
 #define HAVE_MKTIME 1
+#define HAVE_PIPE2 1
 #define HAVE_POLL 1
 #define HAVE_POSIX_MEMALIGN 1
 #define HAVE_PPOLL 1
@@ -283,9 +285,6 @@
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR 1
 #define HAVE_BUILTIN___BUILTIN_TYPES_COMPATIBLE_P 1
 #define HAVE_CLOCK_GETRES 1
-#define RUBY_SETJMP(env) _setjmp(env)
-#define RUBY_LONGJMP(env,val) _longjmp(env,val)
-#define RUBY_JMP_BUF jmp_buf
 #define HAVE_STRUCT_TM_TM_ZONE 1
 #define HAVE_TM_ZONE 1
 #define HAVE_STRUCT_TM_TM_GMTOFF 1
@@ -316,6 +315,9 @@
 #define DLEXT_MAXLEN 3
 #define DLEXT ".so"
 #define LIBDIR_BASENAME "lib"
+#define RUBY_SETJMP(env) _setjmp((env))
+#define RUBY_LONGJMP(env,val) _longjmp((env),val)
+#define RUBY_JMP_BUF jmp_buf
 #define HAVE_PTHREAD_H 1
 #define HAVE_MEMMEM 1
 #define RUBY_PLATFORM "sparc-openbsd"
