@@ -3,8 +3,8 @@
 # changes made to this file will be lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION == "2.1.2" or
-    raise "ruby lib version (2.1.2) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION == "2.1.5" or
+    raise "ruby lib version (2.1.5) doesn't match executable version (#{RUBY_VERSION})"
 
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.1/i386-openbsd")
   DESTDIR = '' unless defined? DESTDIR
@@ -13,8 +13,8 @@ module RbConfig
   CONFIG["MAJOR"] = "2"
   CONFIG["MINOR"] = "1"
   CONFIG["TEENY"] = "0"
-  CONFIG["PATCHLEVEL"] = "95"
-  CONFIG["INSTALL"] = '/usr/bin/install -c -o root -g bin'
+  CONFIG["PATCHLEVEL"] = "273"
+  CONFIG["INSTALL"] = '/usr/obj/ports/ruby-2.1.5/bin/install -c '
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "ruby21"
@@ -25,8 +25,8 @@ module RbConfig
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " newline.c"
   CONFIG["USE_RUBYGEMS"] = "YES"
-  CONFIG["MANTYPE"] = "man"
-  CONFIG["NROFF"] = "/bin/false"
+  CONFIG["MANTYPE"] = "doc"
+  CONFIG["NROFF"] = ""
   CONFIG["vendorarchhdrdir"] = "$(vendorhdrdir)/$(sitearch)"
   CONFIG["sitearchhdrdir"] = "$(sitehdrdir)/$(sitearch)"
   CONFIG["rubyarchhdrdir"] = "$(rubyhdrdir)/$(arch)"
@@ -36,7 +36,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--program-suffix=21' '--with-soname=ruby21' '--with-ruby-version=minor' '--enable-pthread' '--enable-ipv6' '--disable-option-checking' '--with-tcl-include=/usr/local/include/tcl8.5' '--with-tk-include=/usr/local/include/tk8.5' '--with-tcllib=tcl85' '--with-tklib=tk85' '--with-X11-dir=/usr/X11R6' '--enable-shared' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include' 'CXX=c++' 'CXXFLAGS=-O2 -pipe'"
+  CONFIG["configure_args"] = " '--program-suffix=21' '--with-soname=ruby21' '--with-ruby-version=minor' '--with-mantype=doc' '--enable-pthread' '--enable-ipv6' '--disable-option-checking' '--with-tcl-include=/usr/local/include/tcl8.5' '--with-tk-include=/usr/local/include/tk8.5' '--with-tcllib=tcl85' '--with-tklib=tk85' '--with-X11-dir=/usr/X11R6' '--enable-shared' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include' 'CXX=c++' 'CXXFLAGS=-O2 -pipe'"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
   CONFIG["vendordir"] = "$(rubylibprefix)/vendor_ruby"
@@ -77,7 +77,7 @@ module RbConfig
   CONFIG["LIBRUBYARG"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
   CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_SO_NAME).so"
-  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).so.0.0"
+  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).so.1.0"
   CONFIG["LIBRUBY_A"] = "lib$(RUBY_SO_NAME)-static.a"
   CONFIG["RUBYW_INSTALL_NAME"] = ""
   CONFIG["rubyw_install_name"] = ""
@@ -142,9 +142,9 @@ module RbConfig
   CONFIG["DTRACE"] = ""
   CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["MKDIR_P"] = "mkdir -p"
-  CONFIG["INSTALL_DATA"] = "install -c -o root -g bin -m 444"
-  CONFIG["INSTALL_SCRIPT"] = "install -c -o root -g bin -m 555"
-  CONFIG["INSTALL_PROGRAM"] = "install -c -s -o root -g bin -m 555"
+  CONFIG["INSTALL_DATA"] = "/usr/obj/ports/ruby-2.1.5/bin/install -c  -m 644"
+  CONFIG["INSTALL_SCRIPT"] = "/usr/obj/ports/ruby-2.1.5/bin/install -c  -m 755"
+  CONFIG["INSTALL_PROGRAM"] = "/usr/obj/ports/ruby-2.1.5/bin/install -c -s  -m 755"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["NM"] = "nm"
@@ -177,23 +177,23 @@ module RbConfig
   CONFIG["NACL_SDK_VARIANT"] = ""
   CONFIG["NACL_SDK_ROOT"] = ""
   CONFIG["NACL_TOOLCHAIN"] = ""
-  CONFIG["target_os"] = "openbsd5.6"
+  CONFIG["target_os"] = "openbsd5.7"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "i386"
-  CONFIG["target"] = "i386-unknown-openbsd5.6"
-  CONFIG["host_os"] = "openbsd5.6"
+  CONFIG["target"] = "i386-unknown-openbsd5.7"
+  CONFIG["host_os"] = "openbsd5.7"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "i386"
-  CONFIG["host"] = "i386-unknown-openbsd5.6"
+  CONFIG["host"] = "i386-unknown-openbsd5.7"
   CONFIG["RUBY_VERSION_NAME"] = "$(RUBY_BASE_NAME)-$(ruby_version)"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
-  CONFIG["build_os"] = "openbsd5.6"
+  CONFIG["build_os"] = "openbsd5.7"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "i386"
-  CONFIG["build"] = "i386-unknown-openbsd5.6"
-  CONFIG["RUBY_RELEASE_DATE"] = "2014-05-08"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "2.1.2"
+  CONFIG["build"] = "i386-unknown-openbsd5.7"
+  CONFIG["RUBY_RELEASE_DATE"] = "2014-11-13"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "2.1.5"
   CONFIG["target_alias"] = ""
   CONFIG["host_alias"] = ""
   CONFIG["build_alias"] = ""
@@ -267,3 +267,23 @@ module RbConfig
 end
 autoload :Config, "rbconfig/obsolete.rb" # compatibility for ruby-1.8.4 and older.
 CROSS_COMPILING = nil unless defined? CROSS_COMPILING
+install = '/usr/bin/install -c -o root -g bin'  
+c = RbConfig::CONFIG 
+m = RbConfig::MAKEFILE_CONFIG
+if v = ENV['BSD_INSTALL_SCRIPT']
+  m['INSTALL'] = c['INSTALL'] = v.sub('-m 755', '')
+  m['INSTALL_SCRIPT'] = c['INSTALL_SCRIPT'] = v
+else
+  m['INSTALL'] = c['INSTALL'] = "#{install}"
+  m['INSTALL_SCRIPT'] = c['INSTALL_SCRIPT'] = "#{install} -m 755"
+end
+if v = ENV['BSD_INSTALL_PROGRAM']
+  m['INSTALL_PROGRAM'] = c['INSTALL_PROGRAM'] = v
+else
+  m['INSTALL_PROGRAM'] = c['INSTALL_PROGRAM'] = "#{install} -s -m 755"
+end
+if v = ENV['BSD_INSTALL_DATA']
+  m['INSTALL_DATA'] = c['INSTALL_DATA'] = v
+else
+  m['INSTALL_DATA'] = c['INSTALL_DATA'] = "#{install} -m 644"
+end
